#include "fst.h"

int main(void) {
    return 0;
}
